==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/ecrire/lang/public_zh.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=zh
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => '主页', # MODIF
	'article' => 'Article', # NEW
	'articles' => '文章',
	'articles_auteur' => '该作者的文章',
	'articles_populaires' => '热门文章',
	'articles_rubrique' => '此栏下的文章',
	'aucun_article' => '该地址下没有文章',
	'aucun_auteur' => '该地址下没有作者',
	'aucun_site' => '该地址下没有站点',
	'aucune_breve' => '该地址下没有简要',
	'aucune_rubrique' => '该地址下没有专栏',
	'auteur' => 'Auteur', # NEW
	'autres' => 'Autres', # NEW
	'autres_breves' => '其它简要',
	'autres_groupes_mots_clefs' => '其它关键词组',
	'autres_sites' => '其它站点',

	// B
	'bonjour' => '您好',

	// C
	'commenter_site' => '评论站点',
	'contact' => 'Contact', # NEW
	'copie_document_impossible' => 'Impossible de copier le document', # NEW

	// D
	'date' => '日期',
	'dernier_ajout' => '最新添入',
	'dernieres_breves' => '最新简要',
	'derniers_articles' => '最新文章',
	'derniers_commentaires' => '最新评论',
	'derniers_messages_forum' => '论坛最近发表的消息',

	// E
	'edition_mode_texte' => '文本编辑模式',
	'en_reponse' => '回复:',
	'en_resume' => '摘要',
	'envoyer_message' => '发送消息',
	'espace_prive' => '私有区',

	// F
	'formats_acceptes' => 'Formats acceptés : @formats@.', # NEW

	// H
	'hierarchie_site' => '站点层次',

	// J
	'jours' => '天',

	// L
	'lien_connecter' => 'Se connecter', # NEW

	// M
	'meme_auteur' => '同一作者',
	'meme_rubrique' => '同一专栏',
	'memes_auteurs' => '同一作者',
	'message' => '消息',
	'messages_forum' => '论坛消息', # MODIF
	'messages_recents' => '最近论坛消息',
	'mots_clef' => 'Mot-clé', # NEW
	'mots_clefs' => '关键词',
	'mots_clefs_meme_groupe' => '同组关键词',

	// N
	'navigation' => '导航',
	'nom' => '名字',
	'nouveautes' => '新变动',
	'nouveautes_web' => '新页面',
	'nouveaux_articles' => '新文章',
	'nouvelles_breves' => '新要闻',

	// P
	'page_precedente' => '前一页',
	'page_suivante' => '后一页',
	'par_auteur' => '按照',
	'participer_site' => '通过email注册得到访问码,您可以在本站点上得到一个活动区并发表您自己的文章.',
	'plan_site' => '站点地图',
	'popularite' => '热点',
	'poster_message' => '发表消息',
	'proposer_site' => 'Vous pouvez proposer un site à ajouter dans cette rubrique :', # NEW

	// R
	'repondre_article' => '回复文章',
	'repondre_breve' => '回复简要',
	'resultats_recherche' => '搜索结果',
	'retour_debut_forums' => '返回论坛顶',
	'rubrique' => '专栏',
	'rubriques' => '专栏',

	// S
	'signatures_petition' => '签名',
	'site_realise_avec_spip' => '使用SPIP建立的站点',
	'sites_web' => '网站',
	'sous_rubriques' => '子专栏',
	'spam' => 'Spam', # NEW
	'suite' => '继续',
	'sur_web' => '在网上',
	'syndiquer_rubrique' => '联合该专栏',
	'syndiquer_site' => '联合整个站点',

	// T
	'texte_lettre_information' => '站点时事通讯',
	'texte_lettre_information_2' => '本封信统计自下述时间发表的文章和简要', # MODIF

	// V
	'ver_imprimer' => '打印版本',
	'voir_en_ligne' => '在线预览',
	'voir_squelette' => 'voir le squelette de cette page' # NEW
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/ecrire/lang/public_zh.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=zh
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => '主页', # MODIF
	'article' => '文章', # MODIF
	'articles' => '文章',
	'articles_auteur' => '该作者的文章',
	'articles_populaires' => '热门文章',
	'articles_rubrique' => '此栏下的文章',
	'aucun_article' => '该地址下没有文章',
	'aucun_auteur' => '该地址下没有作者',
	'aucun_site' => '该地址下没有站点',
	'aucune_breve' => '该地址下没有简要',
	'aucune_rubrique' => '该地址下没有专栏',
	'auteur' => '作者', # MODIF
	'autres' => '其它', # MODIF
	'autres_breves' => '其它简要',
	'autres_groupes_mots_clefs' => '其它关键词组',
	'autres_sites' => '其它站点',

	// B
	'bonjour' => '您好',

	// C
	'commenter_site' => '评论站点',
	'contact' => '联络', # MODIF
	'copie_document_impossible' => '不能复制文件', # MODIF

	// D
	'date' => '日期',
	'dernier_ajout' => '最新添入',
	'dernieres_breves' => '最新简要',
	'derniers_articles' => '最新文章',
	'derniers_commentaires' => '最新评论',
	'derniers_messages_forum' => '论坛最近发表的消息',

	// E
	'edition_mode_texte' => '文本编辑模式',
	'en_reponse' => '回复:',
	'en_resume' => '摘要',
	'envoyer_message' => '发送消息',
	'espace_prive' => '私有区',

	// F
	'formats_acceptes' => ' 合格的格式: @formats@.', # MODIF

	// H
	'hierarchie_site' => '站点层次',

	// J
	'jours' => '天',

	// L
	'lien_connecter' => '登陆', # MODIF

	// M
	'meme_auteur' => '同一作者',
	'meme_rubrique' => '同一专栏',
	'memes_auteurs' => '同一作者',
	'message' => '消息',
	'messages_forum' => '论坛消息', # MODIF
	'messages_recents' => '最近论坛消息',
	'mots_clef' => 'Mot-clé', # NEW
	'mots_clefs' => '关键词',
	'mots_clefs_meme_groupe' => '同组关键词',

	// N
	'navigation' => '导航',
	'nom' => '名字',
	'nouveautes' => '新变动',
	'nouveautes_web' => '新页面',
	'nouveaux_articles' => '新文章',
	'nouvelles_breves' => '新要闻',

	// P
	'page_precedente' => '前一页',
	'page_suivante' => '后一页',
	'par_auteur' => '按照',
	'participer_site' => '通过email注册得到访问码,您可以在本站点上得到一个活动区并发表您自己的文章.',
	'plan_site' => '站点地图',
	'popularite' => '热点',
	'poster_message' => '发表消息',
	'proposer_site' => 'Vous pouvez proposer un site à ajouter dans cette rubrique :', # NEW

	// R
	'repondre_article' => '回复文章',
	'repondre_breve' => '回复简要',
	'resultats_recherche' => '搜索结果',
	'retour_debut_forums' => '返回论坛顶',
	'rubrique' => '专栏',
	'rubriques' => '专栏',

	// S
	'signatures_petition' => '签名',
	'site_realise_avec_spip' => '使用SPIP建立的站点',
	'sites_web' => '网站',
	'sous_rubriques' => '子专栏',
	'spam' => '垃圾邮件', # MODIF
	'suite' => '继续',
	'sur_web' => '在网上',
	'syndiquer_rubrique' => '联合该专栏',
	'syndiquer_site' => '联合整个站点',

	// T
	'texte_lettre_information' => '站点时事通讯',
	'texte_lettre_information_2' => '本封信统计自下述时间发表的文章和简要', # MODIF

	// V
	'ver_imprimer' => '打印版本',
	'voir_en_ligne' => '在线预览',
	'voir_squelette' => 'voir le squelette de cette page' # NEW
);

?>
